.. os-ken documentation master file, created by
   sphinx-quickstart on Tue Jul  9 22:26:36 2013.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

======================================
Welcome to the documentation of os_ken
======================================

Contents:

.. toctree::
   :maxdepth: 2

   readme
   library/index
   contributor/index
   configuration/index
   user/index
   admin/index
   reference/index

Archived Contents:

.. note::

   Contents here are imported from the upstream Ryu documentation.
   They will be merged into the OS-Ken documentation gradually.

.. toctree::
   :maxdepth: 2

   developing.rst
   configuration.rst
   tests.rst
   snort_integrate.rst
   app.rst

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
